from django.conf.urls.static import static
from django.urls import path, re_path, include
from django.conf import settings
from . import views
from pathlib import Path


bottom = [
    re_path(r'^(?P<path>.*)$', views.HomeView.as_view()) # XXX no comma at the end!
]


if getattr(settings, "FRONTEND_DEV_MODE", False):
    top = [
        re_path(r'^(?P<path>.*\.hot-update\.(js|json))$', views.hot_update), # \.[0-9a-z]{20}
        re_path('^react-static/(?P<path>.+)$', views.react_static)
    ]
else:
    top = [
        static("/react-static/", document_root=str(Path(settings.BASE_DIR) / "frontend" / "build" / "react-static"))
    ]



from django import template
from django.utils.safestring import SafeString
import requests, os, re
from django.conf import settings


register = template.Library()


@register.inclusion_tag("logicore_django_react/include_react_css.html")
def include_react_css(context):
    return {"FRONTEND_DEV_MODE": getattr(settings, "FRONTEND_DEV_MODE", False)}


@register.inclusion_tag("logicore_django_react/include_react_js.html")
def include_react_js(context):
    return {"FRONTEND_DEV_MODE": getattr(settings, "FRONTEND_DEV_MODE", False)}



from django import template
from django.utils.safestring import SafeString
import requests, os, re
from django.conf import settings


register = template.Library()


@register.simple_tag(takes_context=True)
def include_react_dev(context):
    port = getattr(settings, "LOGICORE_DJANGO_REACT_PORT", 3000)
    if not getattr(settings, "FRONTEND_DEV_MODE", False):
        return ''
    return SafeString(
        ' '.join(re.findall(r'<script [^>]+></script>', requests.get(f'http://127.0.0.1:{port}/').text.replace('/static/', '/react-static/')))
    )



from django.views.generic import TemplateView
from proxy.views import proxy_view
from django.conf import settings


class HomeView(TemplateView):
    template_name = getattr(
        settings,
        "LOGICORE_DJANGO_REACT_TEMPLATE",
        "logicore_django_react/home.html"
    )


port = getattr(settings, "LOGICORE_DJANGO_REACT_PORT", 3000)


def react_static(request, path):
    if path.lower().endswith(".css") or path.lower().endswith(".js"):
        remoteurl = f"http://127.0.0.1:{port}/static/" + path
    else:
        remoteurl = f"http://127.0.0.1:{port}/react-static/" + path
    return proxy_view(request, remoteurl, {})


def hot_update(request, path):
    remoteurl = f"http://127.0.0.1:{port}/" + path
    return proxy_view(request, remoteurl, {})
